aboutsummaryrefslogtreecommitdiffstats
path: root/core/interfaces.go
diff options
context:
space:
mode:
Diffstat (limited to 'core/interfaces.go')
-rw-r--r--core/interfaces.go7
1 files changed, 5 insertions, 2 deletions
diff --git a/core/interfaces.go b/core/interfaces.go
index aa4756e..68f210e 100644
--- a/core/interfaces.go
+++ b/core/interfaces.go
@@ -87,8 +87,11 @@ type Governance interface {
// Get block proposing interval (in milliseconds).
GetBlockProposingInterval() int
- // Get Number of Chains.
- GetChainNumber() uint32
+ // Get Number of shards.
+ GetNumShards() uint32
+
+ // Get Number of chains.
+ GetNumChains() uint32
// Get Genesis CRS.
GetGenesisCRS() string